@@ -21,6 +21,9 @@ class date(object):
                   "192.168.84.66"]
         return random.choice(ipList)
 
+    def getAentHostIp(self):
+        ip='10.4.15.54'
+        return ip
 
     def getIpVR(self):
         return '{ip1}.{ip2}.{ip3}.{ip4}'.format(ip1=10, ip2=random.choice(range(10, 250)),
