@@ -82,7 +82,8 @@ def filed(key,inquire=[]):
         'FutureTime': ParaDateFiledServer().getFutureTime,
         'RoleId_user': DataManage.DataManage_Storage().RoleId_user,
         'mailUser':testMail.date().getMailUser,
-        'mailPass':testMail.date().getMailPass
+        'mailPass':testMail.date().getMailPass,
+        'm_id':arPort.inputs().createarPortId
     }
 
     switcher = SERVICE_KPI_
